Index: content/browser/service_worker/service_worker_client_utils.h |
diff --git a/content/browser/service_worker/service_worker_client_utils.h b/content/browser/service_worker/service_worker_client_utils.h |
index be46f6c13e78b3ce44d5ece4aac6f074d98e4f60..24697191e176c4c8f9e03ac05e25acdfce37d4f9 100644 |
--- a/content/browser/service_worker/service_worker_client_utils.h |
+++ b/content/browser/service_worker/service_worker_client_utils.h |
@@ -37,9 +37,11 @@ using ClientsCallback = base::Callback<void(ServiceWorkerClients* clients)>; |
void FocusWindowClient(ServiceWorkerProviderHost* provider_host, |
const ClientCallback& callback); |
-// Opens a new window and navigates it to |url|. |callback| is called with the |
-// window's client information on completion. |
-void OpenWindow(const GURL& url, |
+// Opens a new window and navigates it to |url|. |redirect_url| is the last |
+// navigation occured before |url|. |callback| is called with the window's |
+// client information on completion. |
+void OpenWindow(const GURL& redirect_url, |
+ const GURL& url, |
const GURL& script_url, |
int worker_process_id, |
const base::WeakPtr<ServiceWorkerContextCore>& context, |